snakebacon
==========

.. image:: https://travis-ci.org/brews/snakebacon.svg?branch=master
    :target: https://travis-ci.org/brews/snakebacon


The project is under heavy development. It may eat your hamster. Beware. Hic sunt dracones.
